@@ -247,4 +247,27 @@ sub insert_space {
     } [], @_;
 }
 
+sub decode_argv {
+    map {
+	utf8::is_utf8($_) ? $_ : decode('utf8', $_);
+    }
+    @_;
+}
+
+sub make_options {
+    map {
+	# "foo_bar" -> "foo_bar|foo-bar|foobar"
+	s{^(?=\w+_)(\w+)\K}{
+	    "|" . $1 =~ tr[_][-]r . "|" . $1 =~ tr[_][]dr
+	}er;
+    }
+    grep {
+	s/#.*//;
+	s/\s+//g;
+	/\S/;
+    }
+    map { split /\n+/ }
+    @_;
+}
+
 1;
